@@ -3,7 +3,7 @@
 #
 # $Id: pkgIndex.tcl.in 209 2009-03-03 17:19:05Z nijtmans $
 
-package ifneeded img::base 1.4 [list load [file join $dir libtkimg14.so.0.0]]
+package ifneeded img::base 1.4.2 [list load [file join $dir libtkimg142.so.0.0]]
 
 # Compatibility hack. When asking for the old name of the package
 # then load all format handlers and base libraries provided by tkImg.
@@ -16,7 +16,7 @@ package ifneeded img::base 1.4 [list load [file join $dir libtkimg14.so.0.0]]
 # Therefore file formats with some "magic" identifier, which can be
 # recognized safely, should be added at the end of this list.
 
-package ifneeded Img 1.4 {
+package ifneeded Img 1.4.2 {
     package require img::window
     package require img::tga
     package require img::ico
@@ -33,6 +33,6 @@ package ifneeded Img 1.4 {
     package require img::ppm
     package require img::gif
     package require img::pixmap
-    package provide Img 1.4
+    package provide Img 1.4.2
 }
 
